# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_data_provider/data_provider.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_data_provider/data_provider.proto',
  package='th2.data_provider',
  syntax='proto3',
  serialized_options=b'\n\"com.exactpro.th2.dataprovider.grpcP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*th2_grpc_data_provider/data_provider.proto\x12\x11th2.data_provider\x1a\x1cth2_grpc_common/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x17\n\x15MessageStreamsRequest\"\x17\n\x15MessageFiltersRequest\"\x15\n\x13\x45ventFiltersRequest\"\xe3\x02\n\rEventResponse\x12\x1a\n\x08\x65vent_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\x12\x1a\n\x08\x62\x61tch_id\x18\x03 \x01(\x0b\x32\x08.EventID\x12\x12\n\nis_batched\x18\x04 \x01(\x08\x12\x33\n\x0fstart_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x06status\x18\x07 \x01(\x0e\x32\x0c.EventStatus\x12\x12\n\nevent_name\x18\x08 \x01(\t\x12\x12\n\nevent_type\x18\t \x01(\t\x12\x0c\n\x04\x62ody\x18\n \x01(\x0c\x12\'\n\x13\x61ttached_message_id\x18\x0b \x03(\x0b\x32\n.MessageID\"\xc9\x01\n\rEventMetadata\x12\x1a\n\x08\x65vent_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x06status\x18\x04 \x01(\x0e\x32\x0c.EventStatus\x12\x12\n\nevent_name\x18\x05 \x01(\t\x12\x12\n\nevent_type\x18\x06 \x01(\t\"(\n\x10\x42ulkEventRequest\x12\x14\n\x02id\x18\x01 \x03(\x0b\x32\x08.EventID\"D\n\x11\x42ulkEventResponse\x12/\n\x05\x65vent\x18\x01 \x03(\x0b\x32 .th2.data_provider.EventResponse\"<\n\x10MessageGroupItem\x12\x19\n\x07message\x18\x01 \x01(\x0b\x32\x08.Message\x12\r\n\x05match\x18\x02 \x01(\x08\"\xd7\x01\n\x14MessageGroupResponse\x12\x1e\n\nmessage_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x62ody_raw\x18\x03 \x01(\x0c\x12#\n\x11\x61ttached_event_id\x18\x04 \x03(\x0b\x32\x08.EventID\x12\x39\n\x0cmessage_item\x18\x05 \x03(\x0b\x32#.th2.data_provider.MessageGroupItem\"G\n\x11\x46ilterInfoRequest\x12\x32\n\x0b\x66ilter_name\x18\x01 \x01(\x0b\x32\x1d.th2.data_provider.FilterName\"\x1a\n\nFilterName\x12\x0c\n\x04name\x18\x01 \x01(\t\"I\n\x13\x46ilterNamesResponse\x12\x32\n\x0b\x66ilter_name\x18\x01 \x03(\x0b\x32\x1d.th2.data_provider.FilterName\"\x90\x01\n\x0f\x46ilterParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32&.th2.data_provider.FilterParameterType\x12+\n\rdefault_value\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04hint\x18\x04 \x01(\t\"\x86\x01\n\x12\x46ilterInfoResponse\x12+\n\x04name\x18\x01 \x01(\x0b\x32\x1d.th2.data_provider.FilterName\x12\x0c\n\x04hint\x18\x02 \x01(\t\x12\x35\n\tparameter\x18\x03 \x03(\x0b\x32\".th2.data_provider.FilterParameter\"`\n\x13MessageMatchRequest\x12\x1e\n\nmessage_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12)\n\x06\x66ilter\x18\x02 \x03(\x0b\x32\x19.th2.data_provider.Filter\"Z\n\x11\x45ventMatchRequest\x12\x1a\n\x08\x65vent_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12)\n\x06\x66ilter\x18\x02 \x03(\x0b\x32\x19.th2.data_provider.Filter\"\x1e\n\rMatchResponse\x12\r\n\x05match\x18\x01 \x01(\x08\"h\n\x06\x46ilter\x12+\n\x04name\x18\x01 \x01(\x0b\x32\x1d.th2.data_provider.FilterName\x12\x10\n\x08negative\x18\x02 \x01(\x08\x12\r\n\x05value\x18\x03 \x03(\t\x12\x10\n\x08\x63onjunct\x18\x04 \x01(\x08\"\xad\x04\n\x12\x45ventSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x0cparent_event\x18\x03 \x01(\x0b\x32\x08.EventID\x12\x39\n\x10search_direction\x18\x04 \x01(\x0e\x32\x1f.th2.data_provider.TimeRelation\x12 \n\x0eresume_from_id\x18\x05 \x01(\x0b\x32\x08.EventID\x12\x37\n\x12result_count_limit\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\tkeep_open\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x10limit_for_parent\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\rmetadata_only\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11\x61ttached_messages\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x06\x66ilter\x18\x0b \x03(\x0b\x32\x19.th2.data_provider.Filter\"\xd3\x01\n\x13\x45ventSearchResponse\x12\x31\n\x05\x65vent\x18\x01 \x01(\x0b\x32 .th2.data_provider.EventResponseH\x00\x12:\n\x0e\x65vent_metadata\x18\x02 \x01(\x0b\x32 .th2.data_provider.EventMetadataH\x00\x12\x45\n\x14\x65vent_stream_pointer\x18\x03 \x01(\x0b\x32%.th2.data_provider.EventStreamPointerH\x00\x42\x06\n\x04\x64\x61ta\"W\n\x12\x45ventStreamPointer\x12\x13\n\x0bhas_started\x18\x01 \x01(\x08\x12\x11\n\thas_ended\x18\x02 \x01(\x08\x12\x19\n\x07last_id\x18\x03 \x01(\x0b\x32\x08.EventID\"\xf4\x03\n\x14MessageSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x10search_direction\x18\x03 \x01(\x0e\x32\x1f.th2.data_provider.TimeRelation\x12\x37\n\x12result_count_limit\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x30\n\x06stream\x18\x05 \x03(\x0b\x32 .th2.data_provider.MessageStream\x12-\n\tkeep_open\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0estream_pointer\x18\x07 \x03(\x0b\x32\'.th2.data_provider.MessageStreamPointer\x12)\n\x06\x66ilter\x18\x08 \x03(\x0b\x32\x19.th2.data_provider.Filter\x12\x33\n\x0f\x61ttached_events\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xa8\x01\n\x15MessageSearchResponse\x12:\n\x07message\x18\x01 \x01(\x0b\x32\'.th2.data_provider.MessageGroupResponseH\x00\x12K\n\x17message_stream_pointers\x18\x02 \x01(\x0b\x32(.th2.data_provider.MessageStreamPointersH\x00\x42\x06\n\x04\x64\x61ta\"`\n\x15MessageStreamPointers\x12G\n\x16message_stream_pointer\x18\x01 \x03(\x0b\x32\'.th2.data_provider.MessageStreamPointer\"\x95\x01\n\x14MessageStreamPointer\x12\x38\n\x0emessage_stream\x18\x01 \x01(\x0b\x32 .th2.data_provider.MessageStream\x12\x13\n\x0bhas_started\x18\x02 \x01(\x08\x12\x11\n\thas_ended\x18\x03 \x01(\x08\x12\x1b\n\x07last_id\x18\x04 \x01(\x0b\x32\n.MessageID\"<\n\rMessageStream\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\tdirection\x18\x02 \x01(\x0e\x32\n.Direction\"Q\n\x16MessageStreamsResponse\x12\x37\n\rmessageStream\x18\x01 \x03(\x0b\x32 .th2.data_provider.MessageStream*K\n\x13\x46ilterParameterType\x12\n\n\x06NUMBER\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\n\n\x06STRING\x10\x02\x12\x0f\n\x0bSTRING_LIST\x10\x03*&\n\x0cTimeRelation\x12\x08\n\x04NEXT\x10\x00\x12\x0c\n\x08PREVIOUS\x10\x01\x32\xef\x08\n\x0c\x44\x61taProvider\x12\x38\n\x08getEvent\x12\x08.EventID\x1a .th2.data_provider.EventResponse\"\x00\x12X\n\tgetEvents\x12#.th2.data_provider.BulkEventRequest\x1a$.th2.data_provider.BulkEventResponse\"\x00\x12\x43\n\ngetMessage\x12\n.MessageID\x1a\'.th2.data_provider.MessageGroupResponse\"\x00\x12j\n\x11getMessageStreams\x12(.th2.data_provider.MessageStreamsRequest\x1a).th2.data_provider.MessageStreamsResponse\"\x00\x12g\n\x0esearchMessages\x12\'.th2.data_provider.MessageSearchRequest\x1a(.th2.data_provider.MessageSearchResponse\"\x00\x30\x01\x12\x61\n\x0csearchEvents\x12%.th2.data_provider.EventSearchRequest\x1a&.th2.data_provider.EventSearchResponse\"\x00\x30\x01\x12h\n\x12getMessagesFilters\x12(.th2.data_provider.MessageFiltersRequest\x1a&.th2.data_provider.FilterNamesResponse\"\x00\x12\x64\n\x10getEventsFilters\x12&.th2.data_provider.EventFiltersRequest\x1a&.th2.data_provider.FilterNamesResponse\"\x00\x12\x63\n\x12getEventFilterInfo\x12$.th2.data_provider.FilterInfoRequest\x1a%.th2.data_provider.FilterInfoResponse\"\x00\x12\x65\n\x14getMessageFilterInfo\x12$.th2.data_provider.FilterInfoRequest\x1a%.th2.data_provider.FilterInfoResponse\"\x00\x12V\n\nmatchEvent\x12$.th2.data_provider.EventMatchRequest\x1a .th2.data_provider.MatchResponse\"\x00\x12Z\n\x0cmatchMessage\x12&.th2.data_provider.MessageMatchRequest\x1a .th2.data_provider.MatchResponse\"\x00\x42&\n\"com.exactpro.th2.dataprovider.grpcP\x01\x62\x06proto3'
  ,
  dependencies=[th2__grpc__common_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_FILTERPARAMETERTYPE = _descriptor.EnumDescriptor(
  name='FilterParameterType',
  full_name='th2.data_provider.FilterParameterType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING_LIST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3934,
  serialized_end=4009,
)
_sym_db.RegisterEnumDescriptor(_FILTERPARAMETERTYPE)

FilterParameterType = enum_type_wrapper.EnumTypeWrapper(_FILTERPARAMETERTYPE)
_TIMERELATION = _descriptor.EnumDescriptor(
  name='TimeRelation',
  full_name='th2.data_provider.TimeRelation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEXT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREVIOUS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4011,
  serialized_end=4049,
)
_sym_db.RegisterEnumDescriptor(_TIMERELATION)

TimeRelation = enum_type_wrapper.EnumTypeWrapper(_TIMERELATION)
NUMBER = 0
BOOLEAN = 1
STRING = 2
STRING_LIST = 3
NEXT = 0
PREVIOUS = 1



_MESSAGESTREAMSREQUEST = _descriptor.Descriptor(
  name='MessageStreamsRequest',
  full_name='th2.data_provider.MessageStreamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=210,
)


_MESSAGEFILTERSREQUEST = _descriptor.Descriptor(
  name='MessageFiltersRequest',
  full_name='th2.data_provider.MessageFiltersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=235,
)


_EVENTFILTERSREQUEST = _descriptor.Descriptor(
  name='EventFiltersRequest',
  full_name='th2.data_provider.EventFiltersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=258,
)


_EVENTRESPONSE = _descriptor.Descriptor(
  name='EventResponse',
  full_name='th2.data_provider.EventResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='th2.data_provider.EventResponse.event_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='th2.data_provider.EventResponse.parent_event_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='th2.data_provider.EventResponse.batch_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_batched', full_name='th2.data_provider.EventResponse.is_batched', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='th2.data_provider.EventResponse.start_timestamp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='th2.data_provider.EventResponse.end_timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='th2.data_provider.EventResponse.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_name', full_name='th2.data_provider.EventResponse.event_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='th2.data_provider.EventResponse.event_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='th2.data_provider.EventResponse.body', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_message_id', full_name='th2.data_provider.EventResponse.attached_message_id', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=616,
)


_EVENTMETADATA = _descriptor.Descriptor(
  name='EventMetadata',
  full_name='th2.data_provider.EventMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='th2.data_provider.EventMetadata.event_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='th2.data_provider.EventMetadata.parent_event_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='th2.data_provider.EventMetadata.start_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='th2.data_provider.EventMetadata.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_name', full_name='th2.data_provider.EventMetadata.event_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='th2.data_provider.EventMetadata.event_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=820,
)


_BULKEVENTREQUEST = _descriptor.Descriptor(
  name='BulkEventRequest',
  full_name='th2.data_provider.BulkEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='th2.data_provider.BulkEventRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=862,
)


_BULKEVENTRESPONSE = _descriptor.Descriptor(
  name='BulkEventResponse',
  full_name='th2.data_provider.BulkEventResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='th2.data_provider.BulkEventResponse.event', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=932,
)


_MESSAGEGROUPITEM = _descriptor.Descriptor(
  name='MessageGroupItem',
  full_name='th2.data_provider.MessageGroupItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='th2.data_provider.MessageGroupItem.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match', full_name='th2.data_provider.MessageGroupItem.match', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=994,
)


_MESSAGEGROUPRESPONSE = _descriptor.Descriptor(
  name='MessageGroupResponse',
  full_name='th2.data_provider.MessageGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='th2.data_provider.MessageGroupResponse.message_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='th2.data_provider.MessageGroupResponse.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_raw', full_name='th2.data_provider.MessageGroupResponse.body_raw', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_event_id', full_name='th2.data_provider.MessageGroupResponse.attached_event_id', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_item', full_name='th2.data_provider.MessageGroupResponse.message_item', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=997,
  serialized_end=1212,
)


_FILTERINFOREQUEST = _descriptor.Descriptor(
  name='FilterInfoRequest',
  full_name='th2.data_provider.FilterInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter_name', full_name='th2.data_provider.FilterInfoRequest.filter_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1285,
)


_FILTERNAME = _descriptor.Descriptor(
  name='FilterName',
  full_name='th2.data_provider.FilterName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='th2.data_provider.FilterName.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1287,
  serialized_end=1313,
)


_FILTERNAMESRESPONSE = _descriptor.Descriptor(
  name='FilterNamesResponse',
  full_name='th2.data_provider.FilterNamesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter_name', full_name='th2.data_provider.FilterNamesResponse.filter_name', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1388,
)


_FILTERPARAMETER = _descriptor.Descriptor(
  name='FilterParameter',
  full_name='th2.data_provider.FilterParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='th2.data_provider.FilterParameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='th2.data_provider.FilterParameter.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='th2.data_provider.FilterParameter.default_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='th2.data_provider.FilterParameter.hint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1391,
  serialized_end=1535,
)


_FILTERINFORESPONSE = _descriptor.Descriptor(
  name='FilterInfoResponse',
  full_name='th2.data_provider.FilterInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='th2.data_provider.FilterInfoResponse.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='th2.data_provider.FilterInfoResponse.hint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='th2.data_provider.FilterInfoResponse.parameter', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1538,
  serialized_end=1672,
)


_MESSAGEMATCHREQUEST = _descriptor.Descriptor(
  name='MessageMatchRequest',
  full_name='th2.data_provider.MessageMatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='th2.data_provider.MessageMatchRequest.message_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='th2.data_provider.MessageMatchRequest.filter', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1674,
  serialized_end=1770,
)


_EVENTMATCHREQUEST = _descriptor.Descriptor(
  name='EventMatchRequest',
  full_name='th2.data_provider.EventMatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='th2.data_provider.EventMatchRequest.event_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='th2.data_provider.EventMatchRequest.filter', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1772,
  serialized_end=1862,
)


_MATCHRESPONSE = _descriptor.Descriptor(
  name='MatchResponse',
  full_name='th2.data_provider.MatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='th2.data_provider.MatchResponse.match', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1864,
  serialized_end=1894,
)


_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='th2.data_provider.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='th2.data_provider.Filter.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative', full_name='th2.data_provider.Filter.negative', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='th2.data_provider.Filter.value', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conjunct', full_name='th2.data_provider.Filter.conjunct', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1896,
  serialized_end=2000,
)


_EVENTSEARCHREQUEST = _descriptor.Descriptor(
  name='EventSearchRequest',
  full_name='th2.data_provider.EventSearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='th2.data_provider.EventSearchRequest.start_timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='th2.data_provider.EventSearchRequest.end_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event', full_name='th2.data_provider.EventSearchRequest.parent_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_direction', full_name='th2.data_provider.EventSearchRequest.search_direction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resume_from_id', full_name='th2.data_provider.EventSearchRequest.resume_from_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_count_limit', full_name='th2.data_provider.EventSearchRequest.result_count_limit', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_open', full_name='th2.data_provider.EventSearchRequest.keep_open', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_for_parent', full_name='th2.data_provider.EventSearchRequest.limit_for_parent', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_only', full_name='th2.data_provider.EventSearchRequest.metadata_only', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_messages', full_name='th2.data_provider.EventSearchRequest.attached_messages', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='th2.data_provider.EventSearchRequest.filter', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2003,
  serialized_end=2560,
)


_EVENTSEARCHRESPONSE = _descriptor.Descriptor(
  name='EventSearchResponse',
  full_name='th2.data_provider.EventSearchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='th2.data_provider.EventSearchResponse.event', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_metadata', full_name='th2.data_provider.EventSearchResponse.event_metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_stream_pointer', full_name='th2.data_provider.EventSearchResponse.event_stream_pointer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='th2.data_provider.EventSearchResponse.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2563,
  serialized_end=2774,
)


_EVENTSTREAMPOINTER = _descriptor.Descriptor(
  name='EventStreamPointer',
  full_name='th2.data_provider.EventStreamPointer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_started', full_name='th2.data_provider.EventStreamPointer.has_started', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_ended', full_name='th2.data_provider.EventStreamPointer.has_ended', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_id', full_name='th2.data_provider.EventStreamPointer.last_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2776,
  serialized_end=2863,
)


_MESSAGESEARCHREQUEST = _descriptor.Descriptor(
  name='MessageSearchRequest',
  full_name='th2.data_provider.MessageSearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='th2.data_provider.MessageSearchRequest.start_timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='th2.data_provider.MessageSearchRequest.end_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_direction', full_name='th2.data_provider.MessageSearchRequest.search_direction', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_count_limit', full_name='th2.data_provider.MessageSearchRequest.result_count_limit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='th2.data_provider.MessageSearchRequest.stream', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_open', full_name='th2.data_provider.MessageSearchRequest.keep_open', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_pointer', full_name='th2.data_provider.MessageSearchRequest.stream_pointer', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='th2.data_provider.MessageSearchRequest.filter', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_events', full_name='th2.data_provider.MessageSearchRequest.attached_events', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2866,
  serialized_end=3366,
)


_MESSAGESEARCHRESPONSE = _descriptor.Descriptor(
  name='MessageSearchResponse',
  full_name='th2.data_provider.MessageSearchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='th2.data_provider.MessageSearchResponse.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_stream_pointers', full_name='th2.data_provider.MessageSearchResponse.message_stream_pointers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='th2.data_provider.MessageSearchResponse.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3369,
  serialized_end=3537,
)


_MESSAGESTREAMPOINTERS = _descriptor.Descriptor(
  name='MessageStreamPointers',
  full_name='th2.data_provider.MessageStreamPointers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_stream_pointer', full_name='th2.data_provider.MessageStreamPointers.message_stream_pointer', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3539,
  serialized_end=3635,
)


_MESSAGESTREAMPOINTER = _descriptor.Descriptor(
  name='MessageStreamPointer',
  full_name='th2.data_provider.MessageStreamPointer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_stream', full_name='th2.data_provider.MessageStreamPointer.message_stream', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_started', full_name='th2.data_provider.MessageStreamPointer.has_started', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_ended', full_name='th2.data_provider.MessageStreamPointer.has_ended', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_id', full_name='th2.data_provider.MessageStreamPointer.last_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3638,
  serialized_end=3787,
)


_MESSAGESTREAM = _descriptor.Descriptor(
  name='MessageStream',
  full_name='th2.data_provider.MessageStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='th2.data_provider.MessageStream.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='th2.data_provider.MessageStream.direction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3789,
  serialized_end=3849,
)


_MESSAGESTREAMSRESPONSE = _descriptor.Descriptor(
  name='MessageStreamsResponse',
  full_name='th2.data_provider.MessageStreamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messageStream', full_name='th2.data_provider.MessageStreamsResponse.messageStream', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3851,
  serialized_end=3932,
)

_EVENTRESPONSE.fields_by_name['event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTRESPONSE.fields_by_name['parent_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTRESPONSE.fields_by_name['batch_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTRESPONSE.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTRESPONSE.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTRESPONSE.fields_by_name['status'].enum_type = th2__grpc__common_dot_common__pb2._EVENTSTATUS
_EVENTRESPONSE.fields_by_name['attached_message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_EVENTMETADATA.fields_by_name['event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTMETADATA.fields_by_name['parent_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTMETADATA.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTMETADATA.fields_by_name['status'].enum_type = th2__grpc__common_dot_common__pb2._EVENTSTATUS
_BULKEVENTREQUEST.fields_by_name['id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_BULKEVENTRESPONSE.fields_by_name['event'].message_type = _EVENTRESPONSE
_MESSAGEGROUPITEM.fields_by_name['message'].message_type = th2__grpc__common_dot_common__pb2._MESSAGE
_MESSAGEGROUPRESPONSE.fields_by_name['message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_MESSAGEGROUPRESPONSE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGEGROUPRESPONSE.fields_by_name['attached_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_MESSAGEGROUPRESPONSE.fields_by_name['message_item'].message_type = _MESSAGEGROUPITEM
_FILTERINFOREQUEST.fields_by_name['filter_name'].message_type = _FILTERNAME
_FILTERNAMESRESPONSE.fields_by_name['filter_name'].message_type = _FILTERNAME
_FILTERPARAMETER.fields_by_name['type'].enum_type = _FILTERPARAMETERTYPE
_FILTERPARAMETER.fields_by_name['default_value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_FILTERINFORESPONSE.fields_by_name['name'].message_type = _FILTERNAME
_FILTERINFORESPONSE.fields_by_name['parameter'].message_type = _FILTERPARAMETER
_MESSAGEMATCHREQUEST.fields_by_name['message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_MESSAGEMATCHREQUEST.fields_by_name['filter'].message_type = _FILTER
_EVENTMATCHREQUEST.fields_by_name['event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTMATCHREQUEST.fields_by_name['filter'].message_type = _FILTER
_FILTER.fields_by_name['name'].message_type = _FILTERNAME
_EVENTSEARCHREQUEST.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTSEARCHREQUEST.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTSEARCHREQUEST.fields_by_name['parent_event'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTSEARCHREQUEST.fields_by_name['search_direction'].enum_type = _TIMERELATION
_EVENTSEARCHREQUEST.fields_by_name['resume_from_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTSEARCHREQUEST.fields_by_name['result_count_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_EVENTSEARCHREQUEST.fields_by_name['keep_open'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EVENTSEARCHREQUEST.fields_by_name['limit_for_parent'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_EVENTSEARCHREQUEST.fields_by_name['metadata_only'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EVENTSEARCHREQUEST.fields_by_name['attached_messages'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EVENTSEARCHREQUEST.fields_by_name['filter'].message_type = _FILTER
_EVENTSEARCHRESPONSE.fields_by_name['event'].message_type = _EVENTRESPONSE
_EVENTSEARCHRESPONSE.fields_by_name['event_metadata'].message_type = _EVENTMETADATA
_EVENTSEARCHRESPONSE.fields_by_name['event_stream_pointer'].message_type = _EVENTSTREAMPOINTER
_EVENTSEARCHRESPONSE.oneofs_by_name['data'].fields.append(
  _EVENTSEARCHRESPONSE.fields_by_name['event'])
_EVENTSEARCHRESPONSE.fields_by_name['event'].containing_oneof = _EVENTSEARCHRESPONSE.oneofs_by_name['data']
_EVENTSEARCHRESPONSE.oneofs_by_name['data'].fields.append(
  _EVENTSEARCHRESPONSE.fields_by_name['event_metadata'])
_EVENTSEARCHRESPONSE.fields_by_name['event_metadata'].containing_oneof = _EVENTSEARCHRESPONSE.oneofs_by_name['data']
_EVENTSEARCHRESPONSE.oneofs_by_name['data'].fields.append(
  _EVENTSEARCHRESPONSE.fields_by_name['event_stream_pointer'])
_EVENTSEARCHRESPONSE.fields_by_name['event_stream_pointer'].containing_oneof = _EVENTSEARCHRESPONSE.oneofs_by_name['data']
_EVENTSTREAMPOINTER.fields_by_name['last_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_MESSAGESEARCHREQUEST.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGESEARCHREQUEST.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGESEARCHREQUEST.fields_by_name['search_direction'].enum_type = _TIMERELATION
_MESSAGESEARCHREQUEST.fields_by_name['result_count_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_MESSAGESEARCHREQUEST.fields_by_name['stream'].message_type = _MESSAGESTREAM
_MESSAGESEARCHREQUEST.fields_by_name['keep_open'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MESSAGESEARCHREQUEST.fields_by_name['stream_pointer'].message_type = _MESSAGESTREAMPOINTER
_MESSAGESEARCHREQUEST.fields_by_name['filter'].message_type = _FILTER
_MESSAGESEARCHREQUEST.fields_by_name['attached_events'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MESSAGESEARCHRESPONSE.fields_by_name['message'].message_type = _MESSAGEGROUPRESPONSE
_MESSAGESEARCHRESPONSE.fields_by_name['message_stream_pointers'].message_type = _MESSAGESTREAMPOINTERS
_MESSAGESEARCHRESPONSE.oneofs_by_name['data'].fields.append(
  _MESSAGESEARCHRESPONSE.fields_by_name['message'])
_MESSAGESEARCHRESPONSE.fields_by_name['message'].containing_oneof = _MESSAGESEARCHRESPONSE.oneofs_by_name['data']
_MESSAGESEARCHRESPONSE.oneofs_by_name['data'].fields.append(
  _MESSAGESEARCHRESPONSE.fields_by_name['message_stream_pointers'])
_MESSAGESEARCHRESPONSE.fields_by_name['message_stream_pointers'].containing_oneof = _MESSAGESEARCHRESPONSE.oneofs_by_name['data']
_MESSAGESTREAMPOINTERS.fields_by_name['message_stream_pointer'].message_type = _MESSAGESTREAMPOINTER
_MESSAGESTREAMPOINTER.fields_by_name['message_stream'].message_type = _MESSAGESTREAM
_MESSAGESTREAMPOINTER.fields_by_name['last_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_MESSAGESTREAM.fields_by_name['direction'].enum_type = th2__grpc__common_dot_common__pb2._DIRECTION
_MESSAGESTREAMSRESPONSE.fields_by_name['messageStream'].message_type = _MESSAGESTREAM
DESCRIPTOR.message_types_by_name['MessageStreamsRequest'] = _MESSAGESTREAMSREQUEST
DESCRIPTOR.message_types_by_name['MessageFiltersRequest'] = _MESSAGEFILTERSREQUEST
DESCRIPTOR.message_types_by_name['EventFiltersRequest'] = _EVENTFILTERSREQUEST
DESCRIPTOR.message_types_by_name['EventResponse'] = _EVENTRESPONSE
DESCRIPTOR.message_types_by_name['EventMetadata'] = _EVENTMETADATA
DESCRIPTOR.message_types_by_name['BulkEventRequest'] = _BULKEVENTREQUEST
DESCRIPTOR.message_types_by_name['BulkEventResponse'] = _BULKEVENTRESPONSE
DESCRIPTOR.message_types_by_name['MessageGroupItem'] = _MESSAGEGROUPITEM
DESCRIPTOR.message_types_by_name['MessageGroupResponse'] = _MESSAGEGROUPRESPONSE
DESCRIPTOR.message_types_by_name['FilterInfoRequest'] = _FILTERINFOREQUEST
DESCRIPTOR.message_types_by_name['FilterName'] = _FILTERNAME
DESCRIPTOR.message_types_by_name['FilterNamesResponse'] = _FILTERNAMESRESPONSE
DESCRIPTOR.message_types_by_name['FilterParameter'] = _FILTERPARAMETER
DESCRIPTOR.message_types_by_name['FilterInfoResponse'] = _FILTERINFORESPONSE
DESCRIPTOR.message_types_by_name['MessageMatchRequest'] = _MESSAGEMATCHREQUEST
DESCRIPTOR.message_types_by_name['EventMatchRequest'] = _EVENTMATCHREQUEST
DESCRIPTOR.message_types_by_name['MatchResponse'] = _MATCHRESPONSE
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['EventSearchRequest'] = _EVENTSEARCHREQUEST
DESCRIPTOR.message_types_by_name['EventSearchResponse'] = _EVENTSEARCHRESPONSE
DESCRIPTOR.message_types_by_name['EventStreamPointer'] = _EVENTSTREAMPOINTER
DESCRIPTOR.message_types_by_name['MessageSearchRequest'] = _MESSAGESEARCHREQUEST
DESCRIPTOR.message_types_by_name['MessageSearchResponse'] = _MESSAGESEARCHRESPONSE
DESCRIPTOR.message_types_by_name['MessageStreamPointers'] = _MESSAGESTREAMPOINTERS
DESCRIPTOR.message_types_by_name['MessageStreamPointer'] = _MESSAGESTREAMPOINTER
DESCRIPTOR.message_types_by_name['MessageStream'] = _MESSAGESTREAM
DESCRIPTOR.message_types_by_name['MessageStreamsResponse'] = _MESSAGESTREAMSRESPONSE
DESCRIPTOR.enum_types_by_name['FilterParameterType'] = _FILTERPARAMETERTYPE
DESCRIPTOR.enum_types_by_name['TimeRelation'] = _TIMERELATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MessageStreamsRequest = _reflection.GeneratedProtocolMessageType('MessageStreamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESTREAMSREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageStreamsRequest)
  })
_sym_db.RegisterMessage(MessageStreamsRequest)

MessageFiltersRequest = _reflection.GeneratedProtocolMessageType('MessageFiltersRequest', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEFILTERSREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageFiltersRequest)
  })
_sym_db.RegisterMessage(MessageFiltersRequest)

EventFiltersRequest = _reflection.GeneratedProtocolMessageType('EventFiltersRequest', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTERSREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.EventFiltersRequest)
  })
_sym_db.RegisterMessage(EventFiltersRequest)

EventResponse = _reflection.GeneratedProtocolMessageType('EventResponse', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.EventResponse)
  })
_sym_db.RegisterMessage(EventResponse)

EventMetadata = _reflection.GeneratedProtocolMessageType('EventMetadata', (_message.Message,), {
  'DESCRIPTOR' : _EVENTMETADATA,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.EventMetadata)
  })
_sym_db.RegisterMessage(EventMetadata)

BulkEventRequest = _reflection.GeneratedProtocolMessageType('BulkEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _BULKEVENTREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.BulkEventRequest)
  })
_sym_db.RegisterMessage(BulkEventRequest)

BulkEventResponse = _reflection.GeneratedProtocolMessageType('BulkEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _BULKEVENTRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.BulkEventResponse)
  })
_sym_db.RegisterMessage(BulkEventResponse)

MessageGroupItem = _reflection.GeneratedProtocolMessageType('MessageGroupItem', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEGROUPITEM,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageGroupItem)
  })
_sym_db.RegisterMessage(MessageGroupItem)

MessageGroupResponse = _reflection.GeneratedProtocolMessageType('MessageGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEGROUPRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageGroupResponse)
  })
_sym_db.RegisterMessage(MessageGroupResponse)

FilterInfoRequest = _reflection.GeneratedProtocolMessageType('FilterInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _FILTERINFOREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.FilterInfoRequest)
  })
_sym_db.RegisterMessage(FilterInfoRequest)

FilterName = _reflection.GeneratedProtocolMessageType('FilterName', (_message.Message,), {
  'DESCRIPTOR' : _FILTERNAME,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.FilterName)
  })
_sym_db.RegisterMessage(FilterName)

FilterNamesResponse = _reflection.GeneratedProtocolMessageType('FilterNamesResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILTERNAMESRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.FilterNamesResponse)
  })
_sym_db.RegisterMessage(FilterNamesResponse)

FilterParameter = _reflection.GeneratedProtocolMessageType('FilterParameter', (_message.Message,), {
  'DESCRIPTOR' : _FILTERPARAMETER,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.FilterParameter)
  })
_sym_db.RegisterMessage(FilterParameter)

FilterInfoResponse = _reflection.GeneratedProtocolMessageType('FilterInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILTERINFORESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.FilterInfoResponse)
  })
_sym_db.RegisterMessage(FilterInfoResponse)

MessageMatchRequest = _reflection.GeneratedProtocolMessageType('MessageMatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEMATCHREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageMatchRequest)
  })
_sym_db.RegisterMessage(MessageMatchRequest)

EventMatchRequest = _reflection.GeneratedProtocolMessageType('EventMatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _EVENTMATCHREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.EventMatchRequest)
  })
_sym_db.RegisterMessage(EventMatchRequest)

MatchResponse = _reflection.GeneratedProtocolMessageType('MatchResponse', (_message.Message,), {
  'DESCRIPTOR' : _MATCHRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MatchResponse)
  })
_sym_db.RegisterMessage(MatchResponse)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.Filter)
  })
_sym_db.RegisterMessage(Filter)

EventSearchRequest = _reflection.GeneratedProtocolMessageType('EventSearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSEARCHREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.EventSearchRequest)
  })
_sym_db.RegisterMessage(EventSearchRequest)

EventSearchResponse = _reflection.GeneratedProtocolMessageType('EventSearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSEARCHRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.EventSearchResponse)
  })
_sym_db.RegisterMessage(EventSearchResponse)

EventStreamPointer = _reflection.GeneratedProtocolMessageType('EventStreamPointer', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSTREAMPOINTER,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.EventStreamPointer)
  })
_sym_db.RegisterMessage(EventStreamPointer)

MessageSearchRequest = _reflection.GeneratedProtocolMessageType('MessageSearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESEARCHREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageSearchRequest)
  })
_sym_db.RegisterMessage(MessageSearchRequest)

MessageSearchResponse = _reflection.GeneratedProtocolMessageType('MessageSearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESEARCHRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageSearchResponse)
  })
_sym_db.RegisterMessage(MessageSearchResponse)

MessageStreamPointers = _reflection.GeneratedProtocolMessageType('MessageStreamPointers', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESTREAMPOINTERS,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageStreamPointers)
  })
_sym_db.RegisterMessage(MessageStreamPointers)

MessageStreamPointer = _reflection.GeneratedProtocolMessageType('MessageStreamPointer', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESTREAMPOINTER,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageStreamPointer)
  })
_sym_db.RegisterMessage(MessageStreamPointer)

MessageStream = _reflection.GeneratedProtocolMessageType('MessageStream', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESTREAM,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageStream)
  })
_sym_db.RegisterMessage(MessageStream)

MessageStreamsResponse = _reflection.GeneratedProtocolMessageType('MessageStreamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESTREAMSRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:th2.data_provider.MessageStreamsResponse)
  })
_sym_db.RegisterMessage(MessageStreamsResponse)


DESCRIPTOR._options = None

_DATAPROVIDER = _descriptor.ServiceDescriptor(
  name='DataProvider',
  full_name='th2.data_provider.DataProvider',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4052,
  serialized_end=5187,
  methods=[
  _descriptor.MethodDescriptor(
    name='getEvent',
    full_name='th2.data_provider.DataProvider.getEvent',
    index=0,
    containing_service=None,
    input_type=th2__grpc__common_dot_common__pb2._EVENTID,
    output_type=_EVENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getEvents',
    full_name='th2.data_provider.DataProvider.getEvents',
    index=1,
    containing_service=None,
    input_type=_BULKEVENTREQUEST,
    output_type=_BULKEVENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMessage',
    full_name='th2.data_provider.DataProvider.getMessage',
    index=2,
    containing_service=None,
    input_type=th2__grpc__common_dot_common__pb2._MESSAGEID,
    output_type=_MESSAGEGROUPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMessageStreams',
    full_name='th2.data_provider.DataProvider.getMessageStreams',
    index=3,
    containing_service=None,
    input_type=_MESSAGESTREAMSREQUEST,
    output_type=_MESSAGESTREAMSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='searchMessages',
    full_name='th2.data_provider.DataProvider.searchMessages',
    index=4,
    containing_service=None,
    input_type=_MESSAGESEARCHREQUEST,
    output_type=_MESSAGESEARCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='searchEvents',
    full_name='th2.data_provider.DataProvider.searchEvents',
    index=5,
    containing_service=None,
    input_type=_EVENTSEARCHREQUEST,
    output_type=_EVENTSEARCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMessagesFilters',
    full_name='th2.data_provider.DataProvider.getMessagesFilters',
    index=6,
    containing_service=None,
    input_type=_MESSAGEFILTERSREQUEST,
    output_type=_FILTERNAMESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getEventsFilters',
    full_name='th2.data_provider.DataProvider.getEventsFilters',
    index=7,
    containing_service=None,
    input_type=_EVENTFILTERSREQUEST,
    output_type=_FILTERNAMESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getEventFilterInfo',
    full_name='th2.data_provider.DataProvider.getEventFilterInfo',
    index=8,
    containing_service=None,
    input_type=_FILTERINFOREQUEST,
    output_type=_FILTERINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMessageFilterInfo',
    full_name='th2.data_provider.DataProvider.getMessageFilterInfo',
    index=9,
    containing_service=None,
    input_type=_FILTERINFOREQUEST,
    output_type=_FILTERINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='matchEvent',
    full_name='th2.data_provider.DataProvider.matchEvent',
    index=10,
    containing_service=None,
    input_type=_EVENTMATCHREQUEST,
    output_type=_MATCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='matchMessage',
    full_name='th2.data_provider.DataProvider.matchMessage',
    index=11,
    containing_service=None,
    input_type=_MESSAGEMATCHREQUEST,
    output_type=_MATCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPROVIDER)

DESCRIPTOR.services_by_name['DataProvider'] = _DATAPROVIDER

# @@protoc_insertion_point(module_scope)



#   Copyright 2020-2021 Exactpro (Exactpro Systems Limited)
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

import json
import os
from distutils.cmd import Command
from distutils.dir_util import copy_tree
from distutils.sysconfig import get_python_lib
from pathlib import Path
from shutil import rmtree

from pkg_resources import resource_filename
from setuptools import setup, find_packages
from setuptools.command.sdist import sdist


class ProtoGenerator(Command):

    description = 'build protobuf modules'
    user_options = [('strict-mode', 's', 'exit with non-zero value if the proto compiling fails')]

    def initialize_options(self):
        self.strict_mode = False

    def finalize_options(self):
        pass

    def run(self):
        proto_path = os.path.abspath('src/main/proto')
        gen_path = os.path.abspath('src/gen/main/python')

        if not os.path.exists(gen_path):
            os.makedirs(gen_path)

        proto_files = []
        for root, _, files in os.walk(proto_path):
            for filename in files:
                if filename.endswith('.proto'):
                    proto_files.append(os.path.abspath(os.path.join(root, filename)))

        protos = [('grpc_tools', '_proto')]
        protos_include = [f'--proto_path={proto_path}'] + \
                         [f'--proto_path={resource_filename(x[0], x[1])}' for x in protos] + \
                         [f'--proto_path={get_python_lib()}']

        from grpc_tools import protoc
        for proto_file in proto_files:
            command = ['grpc_tools.protoc'] + \
                      protos_include + \
                      [f'--python_out={gen_path}', f'--grpc_python_out={gen_path}'] + \
                      [f'--mypy_out={gen_path}'] + \
                      [proto_file]

            if protoc.main(command) != 0:
                if self.strict_mode:
                    raise Exception(f'error: {command} failed')


class CustomDist(sdist):

    def run(self):
        copy_tree(f'src/main/proto/{package_name}', package_name)

        copy_tree(f'src/gen/main/python/{package_name}', package_name)
        copy_tree(f'src/gen/main/services/python/{package_name}', package_name)
        Path(f'{package_name}/__init__.py').touch()
        Path(f'{package_name}/py.typed').touch()

        def make_packages(root_dir):
            for path in Path(root_dir).iterdir():
                if path.is_dir():
                    path.joinpath('__init__.py').touch()
                    make_packages(path)

        make_packages(package_name)

        self.distribution.packages = [''] + find_packages(include=[package_name, f'{package_name}.*'])
        self.distribution.package_data = {'': ['package_info.json'],
                                          **dict.fromkeys(self.distribution.packages[1:],
                                                          ['*.proto', 'py.typed', '*.pyi'])}

        sdist.run(self)

        rmtree(package_name, ignore_errors=True)


with open('package_info.json', 'r') as file:
    package_info = json.load(file)

package_name = package_info['package_name'].replace('-', '_')
package_version = package_info['package_version']

with open('README.md', 'r') as file:
    long_description = file.read()

packages = [''] + find_packages(include=[package_name, f'{package_name}.*'])
package_data = {'': ['package_info.json'],
                **dict.fromkeys(packages[1:], ['*.proto', 'py.typed', '*.pyi'])}


setup(
    name=package_name,
    version=package_version,
    description=package_name,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='TH2-devs',
    author_email='th2-devs@exactprosystems.com',
    url='https://github.com/th2-net/th2-data-provider',
    license='Apache License 2.0',
    python_requires='>=3.7',
    install_requires=[
        'th2-grpc-common~=3.4.0'
    ],
    packages=packages,
    package_data=package_data,
    cmdclass={
        'generate': ProtoGenerator,
        'sdist': CustomDist
    }
)
